@@ -600,7 +600,7 @@ class ListSubscribeView(MailingListView):
                     delivery_status=delivery_status,
                 )
                 if (
-                    type(response) == dict
+                    type(response) is dict
                     and response.get('token_owner')  # noqa: W504
                     == TokenOwner.moderator
                 ):
